@@ -90,6 +90,8 @@ class SubformAwareModelFormOptions(ModelFormOptions):
         # store maximum number of repeated subforms that should be allowed
         self.max_num = getattr(options, 'max_num', None)
         self.can_delete = getattr(options, 'can_delete', True)
+        self.can_order = getattr(options, 'can_order', False)
+        self.extra = getattr(options, 'extra', 1)
         
         self.parsed_fields = None
         if isinstance(self.fields, ParsedFieldList):
@@ -106,7 +108,7 @@ class SubformAwareModelFormOptions(ModelFormOptions):
 
 
 def formfields_for_xmlobject(model, fields=None, exclude=None, widgets=None, options=None,
-        declared_subforms=None, max_num=None):
+        declared_subforms=None, max_num=None, extra=None):
     """
     Returns three sorted dictionaries (:class:`django.utils.datastructures.SortedDict`).
      * The first is a dictionary of form fields based on the
@@ -136,6 +138,7 @@ def formfields_for_xmlobject(model, fields=None, exclude=None, widgets=None, opt
                 the corresponding subform (for a :class:`~eulxml.xmlmap.fields.NodeField`)
                 or a formset (for a :class:`~eulxml.xmlmap.fields.NodeListField`)
     :param max_num: optional value for the maximum number of times a fieldset should repeat.
+    :param max_num: optional value for the number of extra forms to provide.
     """
 
     # first collect fields and excludes for the form and all subforms. base
@@ -239,9 +242,10 @@ def formfields_for_xmlobject(model, fields=None, exclude=None, widgets=None, opt
             if isinstance(field, xmlmap.fields.NodeField):
                 subforms[name] = subform
             elif isinstance(field, xmlmap.fields.NodeListField):
-                #formset_factory is from django core and we link into it here.
+                # formset_factory is from django core and we link into it here.
                 formsets[name] = formset_factory(subform, formset=BaseXmlObjectFormSet,
-                    max_num=subform._meta.max_num, can_delete=subform._meta.can_delete)
+                    max_num=subform._meta.max_num, can_delete=subform._meta.can_delete,
+                    extra=subform._meta.extra, can_order=subform._meta.can_order)
 
                 formsets[name].form_label = form_label
 
@@ -364,6 +368,7 @@ class XmlObjectFormType(type):
         # sort declared fields into sub-form overrides and regular fields
         for fname, f in tmp_fields.iteritems():
             if isinstance(f, SubformField):
+                # FIXME: pass can_delete, can_delete from subformfield to formset? 
                 declared_subforms[fname] = f.formclass
                 # if a declared subform fields has a label specified, store it
                 if hasattr(f, 'form_label') and f.form_label is not None:
@@ -721,7 +726,8 @@ class XmlObjectForm(BaseForm):
 
 
 def xmlobjectform_factory(model, form=XmlObjectForm, fields=None, exclude=None,
-                            widgets=None, max_num=None, label=None, can_delete=True):
+                          widgets=None, max_num=None, label=None, can_delete=True,
+                          extra=None, can_order=False):
     """Dynamically generate a new :class:`XmlObjectForm` class using the
     specified :class:`eulxml.xmlmap.XmlObject` class.
     
@@ -737,8 +743,12 @@ def xmlobjectform_factory(model, form=XmlObjectForm, fields=None, exclude=None,
         attrs['widgets'] = widgets
     if max_num is not None:
         attrs['max_num'] = max_num
+    if extra is not None:
+        attrs['extra'] = extra
     if can_delete is not None:
         attrs['can_delete'] = can_delete
+    if can_order is not None:
+        attrs['can_order'] = can_order
         
     # If parent form class already has an inner Meta, the Meta we're
     # creating needs to inherit from the parent's inner meta.
@@ -784,14 +794,26 @@ class BaseXmlObjectFormSet(BaseFormSet):
             # be removed the first time, so don't consider it an error if it's not present
             if form.instance in self.instances:
                 self.instances.remove(form.instance)
-        for form in self.initial_forms:
-            if form.has_changed():
-                form.update_instance()
-        for form in self.extra_forms:
-            if form.has_changed():
+
+        # if forms can be ordered, remove existing records and re-add
+        # in the appropriate order so that any changes in order are
+        # reflected in the xml
+        if self.can_order:
+            for form in self.ordered_forms:
+                if form.instance in self.instances:
+                    self.instances.remove(form.instance)
                 form.update_instance()
                 self.instances.append(form.instance)
 
+        else:
+            for form in self.initial_forms:
+                if form.has_changed():
+                    form.update_instance()
+            for form in self.extra_forms:
+                if form.has_changed():
+                    form.update_instance()
+                    self.instances.append(form.instance)
+
     # NOTE: when displaying forms that use formsets to the user, it is recommended
     # to re-initialize the form after a successful update before re-displaying it
     # so that the formset forms (initial, deleted, extra) will be re-initialized
@@ -817,12 +839,14 @@ class SubformField(Field):
     In this example, the subform ``part`` on an instance of **MyForm** will be
     created as an instance of **MyFormPart**.
     """
-    def __init__(self, formclass=None, label=None, can_delete=True, *args, **kwargs):
+    def __init__(self, formclass=None, label=None, can_delete=True, can_order=False,
+                 *args, **kwargs):
         if formclass is not None:
             self.formclass = formclass
         if label is not None:
             self.form_label = label
         self.can_delete = can_delete
+        self.can_order = can_order
         
         # may not need to actually call init since we don't really use this as a field
         super(SubformField, self).__init__(*args, **kwargs)
